@@ -25,9 +25,9 @@ NULL
 #' `size`. They also each have aesthetics that control the position of
 #' the line:
 #'
-#'   - `geom_vline`: `xintercept`
-#'   - `geom_hline`: `yintercept`
-#'   - `geom_abline`: `slope` and `intercept`
+#'   - `geom_vline()`: `xintercept`
+#'   - `geom_hline()`: `yintercept`
+#'   - `geom_abline()`: `slope` and `intercept`
 #'
 #' @seealso See [geom_segment()] for a more general approach to
 #'   adding straight line segments to a plot.
@@ -111,7 +111,7 @@ geom_abline <- function(mapping = NULL, data = NULL,
 #' @export
 GeomAbline <- ggproto("GeomAbline", Geom,
   draw_panel = function(data, panel_params, coord) {
-    ranges <- coord$range(panel_params)
+    ranges <- coord$backtransform_range(panel_params)
 
     data$x    <- ranges$x[1]
     data$xend <- ranges$x[2]
