@@ -32,6 +32,11 @@ geom_col <- function(mapping = NULL, data = NULL,
 GeomCol <- ggproto("GeomCol", GeomRect,
   required_aes = c("x", "y"),
 
+  # These aes columns are created by setup_data(). They need to be listed here so
+  # that GeomRect$handle_na() properly removes any bars that fall outside the defined
+  # limits, not just those for which x and y are outside the limits
+  non_missing_aes = c("xmin", "xmax", "ymin", "ymax"),
+
   setup_data = function(data, params) {
     data$width <- data$width %||%
       params$width %||% (resolution(data$x, FALSE) * 0.9)
