@@ -1,18 +1,24 @@
-#' Line segments and curves.
+#' Line segments and curves
 #'
-#' \code{geom_segment} draws a straight line between points (x1, y1) and
-#' (x2, y2). \code{geom_curve} draws a curved line.
+#' `geom_segment` draws a straight line between points (x, y) and
+#' (xend, yend). `geom_curve` draws a curved line. See the underlying
+#' drawing function [grid::curveGrob()] for the parameters that
+#' control the curve.
 #'
-#' @section Aesthetics:
-#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("geom", "segment")}
+#' Both geoms draw a single segment/curve per case. See `geom_path` if you
+#' need to connect points across multiple cases.
 #'
+#' @eval rd_aesthetics("geom", "segment")
 #' @inheritParams layer
 #' @inheritParams geom_point
-#' @param arrow specification for arrow heads, as created by arrow()
-#' @param lineend Line end style (round, butt, square)
-#' @seealso \code{\link{geom_path}} and \code{\link{geom_line}} for multi-
+#' @param arrow specification for arrow heads, as created by arrow().
+#' @param arrow.fill fill colour to use for the arrow head (if closed). `NULL`
+#'        means use `colour` aesthetic.
+#' @param lineend Line end style (round, butt, square).
+#' @param linejoin Line join style (round, mitre, bevel).
+#' @seealso [geom_path()] and [geom_line()] for multi-
 #'   segment lines and paths.
-#' @seealso \code{\link{geom_spoke}} for a segment parameterised by a location
+#' @seealso [geom_spoke()] for a segment parameterised by a location
 #'   (x, y), and an angle and radius.
 #' @export
 #' @examples
@@ -37,6 +43,21 @@
 #'     arrow = arrow(length = unit(0.1,"cm"))) +
 #'   borders("state")
 #'
+#' # Use lineend and linejoin to change the style of the segments
+#' df2 <- expand.grid(
+#'   lineend = c('round', 'butt', 'square'),
+#'   linejoin = c('round', 'mitre', 'bevel'),
+#'   stringsAsFactors = FALSE
+#' )
+#' df2 <- data.frame(df2, y = 1:9)
+#' ggplot(df2, aes(x = 1, y = y, xend = 2, yend = y, label = paste(lineend, linejoin))) +
+#'   geom_segment(
+#'      lineend = df2$lineend, linejoin = df2$linejoin,
+#'      size = 3, arrow = arrow(length = unit(0.3, "inches"))
+#'   ) +
+#'   geom_text(hjust = 'outside', nudge_x = -0.2) +
+#'   xlim(0.5, 2)
+#'
 #' # You can also use geom_segment to recreate plot(type = "h") :
 #' counts <- as.data.frame(table(x = rpois(100,5)))
 #' counts$x <- as.numeric(as.character(counts$x))
@@ -48,7 +69,9 @@ geom_segment <- function(mapping = NULL, data = NULL,
                          stat = "identity", position = "identity",
                          ...,
                          arrow = NULL,
+                         arrow.fill = NULL,
                          lineend = "butt",
+                         linejoin = "round",
                          na.rm = FALSE,
                          show.legend = NA,
                          inherit.aes = TRUE) {
@@ -62,7 +85,9 @@ geom_segment <- function(mapping = NULL, data = NULL,
     inherit.aes = inherit.aes,
     params = list(
       arrow = arrow,
+      arrow.fill = arrow.fill,
       lineend = lineend,
+      linejoin = linejoin,
       na.rm = na.rm,
       ...
     )
@@ -78,8 +103,8 @@ GeomSegment <- ggproto("GeomSegment", Geom,
   non_missing_aes = c("linetype", "size", "shape"),
   default_aes = aes(colour = "black", size = 0.5, linetype = 1, alpha = NA),
 
-  draw_panel = function(data, panel_scales, coord, arrow = NULL,
-                        lineend = "butt", na.rm = FALSE) {
+  draw_panel = function(data, panel_params, coord, arrow = NULL, arrow.fill = NULL,
+                        lineend = "butt", linejoin = "round", na.rm = FALSE) {
 
     data <- remove_missing(data, na.rm = na.rm,
       c("x", "y", "xend", "yend", "linetype", "size", "shape"),
@@ -87,15 +112,17 @@ GeomSegment <- ggproto("GeomSegment", Geom,
     if (empty(data)) return(zeroGrob())
 
     if (coord$is_linear()) {
-      coord <- coord$transform(data, panel_scales)
+      coord <- coord$transform(data, panel_params)
+      arrow.fill <- arrow.fill %||% coord$colour
       return(segmentsGrob(coord$x, coord$y, coord$xend, coord$yend,
         default.units = "native",
         gp = gpar(
           col = alpha(coord$colour, coord$alpha),
-          fill = alpha(coord$colour, coord$alpha),
+          fill = alpha(arrow.fill, coord$alpha),
           lwd = coord$size * .pt,
           lty = coord$linetype,
-          lineend = lineend
+          lineend = lineend,
+          linejoin = linejoin
         ),
         arrow = arrow
       ))
@@ -109,7 +136,7 @@ GeomSegment <- ggproto("GeomSegment", Geom,
     pieces <- rbind(starts, ends)
     pieces <- pieces[order(pieces$group),]
 
-    GeomPath$draw_panel(pieces, panel_scales, coord, arrow = arrow,
+    GeomPath$draw_panel(pieces, panel_params, coord, arrow = arrow,
       lineend = lineend)
   },
 
