@@ -1,4 +1,8 @@
 find_scale <- function(aes, x, env = parent.frame()) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
   type <- scale_type(x)
   candidates <- paste("scale", aes, type, sep = "_")
 
@@ -31,7 +35,24 @@ find_global <- function(name, env, mode = "any") {
   NULL
 }
 
-# Determine default type of a scale
+#' Determine default scale type
+#'
+#' You will need to define a method for this method if you want to extend
+#' ggplot2 to handle new types of data. If you simply want to pass the vector
+#' through as an additional aesthetic, return `"identity"`.
+#'
+#' @param x A vector
+#' @return A character vector of scale types. These will be tried in turn
+#'   to find a default scale. For example, if `scale_type` returns
+#'   `c("foo", "bar")` and the vector is used with the colour aesthetic,
+#'   ggplot2 will first look for `scale_colour_foo` then
+#'   `scale_colour_bar`.
+#' @export
+#' @keywords internal
+#' @examples
+#' scale_type(1:5)
+#' scale_type("test")
+#' scale_type(Sys.Date())
 scale_type <- function(x) UseMethod("scale_type")
 
 #' @export
@@ -41,6 +62,9 @@ scale_type.default <- function(x) {
   "continuous"
 }
 
+#' @export
+scale_type.list <- function(x) "identity"
+
 #' @export
 scale_type.AsIs <- function(x) "identity"
 
