@@ -8,8 +8,8 @@ test_that("binwidth is respected", {
   out <- layer_data(base)
   expect_equal(nrow(out), 2)
   # Adjust tolerance to account for fuzzy breaks adjustment
-  expect_equal(out$xmin, c(1, 1.75), tol = 1e-7)
-  expect_equal(out$xmax, c(1.25, 2), tol = 1e-7)
+  expect_equal(out$xmin, c(1, 1.75), tolerance = 1e-7)
+  expect_equal(out$xmax, c(1.25, 2), tolerance = 1e-7)
 })
 
 test_that("breaks override binwidth", {
@@ -29,3 +29,15 @@ test_that("breaks override binwidth", {
   expect_equal(out$xbin, cut(df$x, adjust_breaks(integer_breaks), include.lowest = TRUE, labels = FALSE))
   expect_equal(out$ybin, cut(df$y, adjust_breaks(half_breaks), include.lowest = TRUE, labels = FALSE))
 })
+
+test_that("breaks are transformed by the scale", {
+  df <- data.frame(x = c(1, 10, 100, 1000), y = 0:3)
+  base <- ggplot(df, aes(x, y)) +
+    stat_bin_2d(
+      breaks = list(x = c(5, 50, 500), y = c(0.5, 1.5, 2.5)))
+
+  out1 <- layer_data(base)
+  out2 <- layer_data(base + scale_x_log10())
+  expect_equal(out1$x, c(27.5, 275))
+  expect_equal(out2$x, c(1.19897, 2.19897))
+})
